#include <stdio.h>
#include <unistd.h>
#include <string.h>
#include <errno.h>
#include <termios.h>

#include "config.h"
#include "imapfilter.h"


extern unsigned int flags;

static struct termios otio, ntio;	/* Original and new tty settings. */


/*
 * Store original term attributes.
 */
int
tty_store(void)
{
	if (isatty(fileno(stdin))) {
		flags |= FLAG_TTY;

		if (tcgetattr(fileno(stdin), &otio)) {
			error("getting term attributes; %s\n", strerror(errno));
			return ERROR_TERMIO;
		}
	}
	return 0;
}


/*
 * Disable echo.
 */
int
tty_disable_echo(void)
{
	if (!(flags & FLAG_TTY))
		return 0;

	ntio = otio;
	ntio.c_lflag &= ~(ECHO | ECHOE | ECHOK | ECHONL);

	flags |= FLAG_TTY_MODIFIED;

	if (tcsetattr(fileno(stdin), TCSAFLUSH, &ntio)) {
		error("setting term attributes; %s\n", strerror(errno));
		return ERROR_TERMIO;
	}
	return 0;
}


/*
 * Restore original term attributes.
 */
int
tty_restore(void)
{
	if (!(flags & FLAG_TTY) || !(flags & FLAG_TTY_MODIFIED))
		return 0;

	if (tcsetattr(fileno(stdin), TCSAFLUSH, &otio)) {
		error("setting term attributes; %s\n", strerror(errno));
		return ERROR_TERMIO;
	}
	flags &= ~(FLAG_TTY_MODIFIED);

	return 0;
}
